
#include "itkBSplineDeformableTransformFix.h"
#include <iostream>

int main( int argc, char *argv[] )
{
  const unsigned int SplineOrder = 1;
  const unsigned int Dimension = 1;

  typedef double CoordRepType;
  typedef itk::BSplineDeformableTransform<CoordRepType, Dimension, SplineOrder >
    TransformType;
  
  typedef TransformType::RegionType RegionType;
  typedef TransformType::ParametersType ParametersType;
  typedef RegionType::SizeType SizeType;
  typedef TransformType::InputPointType PointType;
 
  TransformType::Pointer transform = TransformType::New();
  
  // define grid of size 4 in each dimension
  // default spacing/origin of 1/0
  // So grid points are at 0, 1, 2, and 3.
  RegionType gridregion;
  SizeType gridsize;
  gridsize.Fill( 4 );
  gridregion.SetSize( gridsize );
  transform->SetGridRegion( gridregion );
  
  // impose translation of 10 everywhere inside the valid region
  ParametersType parameters = transform->GetParameters();
  parameters.Fill( 10 );
  transform->SetParameters( parameters );

  PointType inpoint;
  inpoint.Fill( 0 );
  PointType outpoint;
  outpoint.Fill( 0 );
  const unsigned int res = 101;
  const double resd = static_cast<double>(res);
  // Loop from p=-1 to p=4 in res+1 steps.
  for ( unsigned int i = 0; i <= res; ++i )
  {
    const double inpos = -1 + i * (gridsize[0]+1) / resd;
    inpoint.Fill( inpos );
    outpoint = transform->TransformPoint( inpoint );
    std::cout << " inpoint = " << inpoint << "\toutpoint = " << outpoint << std::endl; 
  }

  return 0;
} // end main()

